.. image:: https://img.shields.io/pypi/v/pint-pandas.svg
    :target: https://pypi.python.org/pypi/pint-pandas
    :alt: Latest Version

.. image:: https://readthedocs.org/projects/pip/badge/
    :target: http://pint-pandas.readthedocs.org/
    :alt: Documentation

.. image:: https://img.shields.io/pypi/l/pint-pandas.svg
    :target: https://pypi.python.org/pypi/pint-pandas
    :alt: License

.. image:: https://img.shields.io/pypi/pyversions/pint-pandas.svg
    :target: https://pypi.python.org/pypi/pint-pandas
    :alt: Python Versions

.. image:: https://travis-ci.org/hgrecco/pint-pandas.svg?branch=master
    :target: https://travis-ci.org/hgrecco/pint-pandas
    :alt: CI

.. image:: https://coveralls.io/repos/github/hgrecco/pint-pandas/badge.svg?branch=master 
    :target: https://coveralls.io/github/hgrecco/pint-pandas?branch=master
    :alt: Coverage

.. image:: https://readthedocs.org/projects/pint-pandas/badge/
    :target: http://pint-pandas.readthedocs.org/
    :alt: Docs


